#wildcard
[![PypiDownloads](https://img.shields.io/pypi/dm/pywildcard.svg)](https://pypi.python.org/pypi/pywildcard)

## Install

```bash
pip install pywildcard
```

Link pypi: https://pypi.python.org/pypi/pywildcard
